"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Handler = exports.generateResolvers = exports.typeDefs = exports.debug = void 0;
const apollo_server_micro_1 = require("apollo-server-micro");
const micro_cors_1 = __importDefault(require("micro-cors"));
const debug_1 = __importDefault(require("debug"));
exports.debug = debug_1.default('deepcase:auth:hrs');
exports.typeDefs = apollo_server_micro_1.gql `
  type AuthResult {
    id: String
    token: String
    error: String
  }
  type AuthSendResult {
    id: String
    error: String
  }
  type Auth {
    local(username: String, password: String): AuthResult
    sendCode(address: String): AuthSendResult
    checkCode(sendId: String, code: String): AuthResult
  }
  type Query {
    auth: Auth
  }
`;
exports.generateResolvers = (queryResolvers) => {
    const resolvers = {
        Query: {
            auth: () => (queryResolvers),
        },
    };
    return resolvers;
};
exports.Handler = (resolvers) => {
    const apolloServer = new apollo_server_micro_1.ApolloServer({
        typeDefs: exports.typeDefs,
        resolvers: exports.generateResolvers(resolvers),
        context: () => {
            return {};
        },
    });
    const handler = apolloServer.createHandler({ path: '/api/auth/hrs' });
    const config = {
        api: {
            bodyParser: false,
        },
    };
    const cors = micro_cors_1.default({
        allowMethods: ['POST', 'OPTIONS'],
    });
    return {
        handler: cors(handler),
        config,
    };
};
//# sourceMappingURL=hrs.js.map